diff decoders/voc.c @ 47:ea58bc3b15d7

Added init() and quit() methods.
author Ryan C. Gordon <icculus@icculus.org>
date Sat, 22 Sep 2001 14:41:38 +0000
parents 4a60ee42ca9a
children b13fafb976be
line wrap: on
line diff
--- a/decoders/voc.c	Sat Sep 22 14:41:10 2001 +0000
+++ b/decoders/voc.c	Sat Sep 22 14:41:38 2001 +0000
@@ -51,6 +51,8 @@
 #endif
 
 
+static int VOC_init(void);
+static void VOC_quit(void);
 static int VOC_open(Sound_Sample *sample, const char *ext);
 static void VOC_close(Sound_Sample *sample);
 static Uint32 VOC_read(Sound_Sample *sample);
@@ -64,9 +66,11 @@
         "http://www.icculus.org/SDL_sound/"
     },
 
-    VOC_open,       /* open() method       */
-    VOC_close,      /* close() method       */
-    VOC_read        /* read() method       */
+    VOC_init,       /*  init() method */
+    VOC_quit,       /*  quit() method */
+    VOC_open,       /*  open() method */
+    VOC_close,      /* close() method */
+    VOC_read        /*  read() method */
 };
 
 
@@ -117,6 +121,18 @@
 #define VOC_DATA_16   9
 
 
+static int VOC_init(void)
+{
+    return(1);  /* always succeeds. */
+} /* VOC_init */
+
+
+static void VOC_quit(void)
+{
+    /* it's a no-op. */
+} /* VOC_quit */
+
+
 static __inline__ int voc_check_header(SDL_RWops *src)
 {
     /* VOC magic header */